user

package module
v1.0.20 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2025 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package user is a generated GoMock package.

Index

Constants

This section is empty.

Variables

var File_user_info_proto protoreflect.FileDescriptor
var NewUserServiceClientProxy = func(opts ...client.Option) UserServiceClientProxy {
	return &UserServiceClientProxyImpl{client: client.DefaultClient, opts: opts}
}
var UserServiceServer_ServiceDesc = server.ServiceDesc{
	ServiceName: "trpc.polarbear.user.UserService",
	HandlerType: ((*UserServiceService)(nil)),
	Methods: []server.Method{
		{
			Name: "/trpc.polarbear.user.UserService/GetUserInfo",
			Func: UserServiceService_GetUserInfo_Handler,
		},
		{
			Name: "/trpc.polarbear.user.UserService/Hello",
			Func: UserServiceService_Hello_Handler,
		},
		{
			Name: "/trpc.polarbear.user.UserService/Hello1",
			Func: UserServiceService_Hello1_Handler,
		},
	},
}

UserServiceServer_ServiceDesc descriptor for server.RegisterService.

Functions

func RegisterUserServiceService

func RegisterUserServiceService(s server.Service, svr UserServiceService)

RegisterUserServiceService registers service.

func UserServiceService_GetUserInfo_Handler

func UserServiceService_GetUserInfo_Handler(svr interface{}, ctx context.Context, f server.FilterFunc) (interface{}, error)

func UserServiceService_Hello1_Handler added in v1.0.10

func UserServiceService_Hello1_Handler(svr interface{}, ctx context.Context, f server.FilterFunc) (interface{}, error)

func UserServiceService_Hello_Handler

func UserServiceService_Hello_Handler(svr interface{}, ctx context.Context, f server.FilterFunc) (interface{}, error)

Types

type GetUserInfoReq

type GetUserInfoReq struct {
	Id   string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUserInfoReq) Descriptor deprecated

func (*GetUserInfoReq) Descriptor() ([]byte, []int)

Deprecated: Use GetUserInfoReq.ProtoReflect.Descriptor instead.

func (*GetUserInfoReq) GetId

func (x *GetUserInfoReq) GetId() string

func (*GetUserInfoReq) GetName

func (x *GetUserInfoReq) GetName() string

func (*GetUserInfoReq) ProtoMessage

func (*GetUserInfoReq) ProtoMessage()

func (*GetUserInfoReq) ProtoReflect

func (x *GetUserInfoReq) ProtoReflect() protoreflect.Message

func (*GetUserInfoReq) Reset

func (x *GetUserInfoReq) Reset()

func (*GetUserInfoReq) String

func (x *GetUserInfoReq) String() string

type GetUserInfoResp

type GetUserInfoResp struct {
	User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUserInfoResp) Descriptor deprecated

func (*GetUserInfoResp) Descriptor() ([]byte, []int)

Deprecated: Use GetUserInfoResp.ProtoReflect.Descriptor instead.

func (*GetUserInfoResp) GetUser

func (x *GetUserInfoResp) GetUser() *User

func (*GetUserInfoResp) ProtoMessage

func (*GetUserInfoResp) ProtoMessage()

func (*GetUserInfoResp) ProtoReflect

func (x *GetUserInfoResp) ProtoReflect() protoreflect.Message

func (*GetUserInfoResp) Reset

func (x *GetUserInfoResp) Reset()

func (*GetUserInfoResp) String

func (x *GetUserInfoResp) String() string

type MockUserServiceClientProxy

type MockUserServiceClientProxy struct {
	// contains filtered or unexported fields
}

MockUserServiceClientProxy is a mock of UserServiceClientProxy interface.

func NewMockUserServiceClientProxy

func NewMockUserServiceClientProxy(ctrl *gomock.Controller) *MockUserServiceClientProxy

NewMockUserServiceClientProxy creates a new mock instance.

func (*MockUserServiceClientProxy) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockUserServiceClientProxy) GetUserInfo

GetUserInfo mocks base method.

func (*MockUserServiceClientProxy) Hello

Hello mocks base method.

func (*MockUserServiceClientProxy) Hello1 added in v1.0.10

Hello1 mocks base method.

type MockUserServiceClientProxyMockRecorder

type MockUserServiceClientProxyMockRecorder struct {
	// contains filtered or unexported fields
}

MockUserServiceClientProxyMockRecorder is the mock recorder for MockUserServiceClientProxy.

func (*MockUserServiceClientProxyMockRecorder) GetUserInfo

func (mr *MockUserServiceClientProxyMockRecorder) GetUserInfo(ctx, req any, opts ...any) *gomock.Call

GetUserInfo indicates an expected call of GetUserInfo.

func (*MockUserServiceClientProxyMockRecorder) Hello

func (mr *MockUserServiceClientProxyMockRecorder) Hello(ctx, req any, opts ...any) *gomock.Call

Hello indicates an expected call of Hello.

func (*MockUserServiceClientProxyMockRecorder) Hello1 added in v1.0.10

func (mr *MockUserServiceClientProxyMockRecorder) Hello1(ctx, req any, opts ...any) *gomock.Call

Hello1 indicates an expected call of Hello1.

type MockUserServiceService

type MockUserServiceService struct {
	// contains filtered or unexported fields
}

MockUserServiceService is a mock of UserServiceService interface.

func NewMockUserServiceService

func NewMockUserServiceService(ctrl *gomock.Controller) *MockUserServiceService

NewMockUserServiceService creates a new mock instance.

func (*MockUserServiceService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockUserServiceService) GetUserInfo

GetUserInfo mocks base method.

func (*MockUserServiceService) Hello

Hello mocks base method.

func (*MockUserServiceService) Hello1 added in v1.0.10

Hello1 mocks base method.

type MockUserServiceServiceMockRecorder

type MockUserServiceServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockUserServiceServiceMockRecorder is the mock recorder for MockUserServiceService.

func (*MockUserServiceServiceMockRecorder) GetUserInfo

func (mr *MockUserServiceServiceMockRecorder) GetUserInfo(ctx, req any) *gomock.Call

GetUserInfo indicates an expected call of GetUserInfo.

func (*MockUserServiceServiceMockRecorder) Hello

func (mr *MockUserServiceServiceMockRecorder) Hello(ctx, req any) *gomock.Call

Hello indicates an expected call of Hello.

func (*MockUserServiceServiceMockRecorder) Hello1 added in v1.0.10

func (mr *MockUserServiceServiceMockRecorder) Hello1(ctx, req any) *gomock.Call

Hello1 indicates an expected call of Hello1.

type UnimplementedUserService

type UnimplementedUserService struct{}

func (*UnimplementedUserService) GetUserInfo

func (*UnimplementedUserService) Hello

func (*UnimplementedUserService) Hello1 added in v1.0.10

type User

type User struct {
	Id    string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Name  string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Age   string `protobuf:"bytes,3,opt,name=age,proto3" json:"age,omitempty"`
	Phone string `protobuf:"bytes,4,opt,name=phone,proto3" json:"phone,omitempty"`
	Bg    string `protobuf:"bytes,5,opt,name=bg,proto3" json:"bg,omitempty"`
	// contains filtered or unexported fields
}

func (*User) Descriptor deprecated

func (*User) Descriptor() ([]byte, []int)

Deprecated: Use User.ProtoReflect.Descriptor instead.

func (*User) GetAge

func (x *User) GetAge() string

func (*User) GetBg

func (x *User) GetBg() string

func (*User) GetId

func (x *User) GetId() string

func (*User) GetName

func (x *User) GetName() string

func (*User) GetPhone

func (x *User) GetPhone() string

func (*User) ProtoMessage

func (*User) ProtoMessage()

func (*User) ProtoReflect

func (x *User) ProtoReflect() protoreflect.Message

func (*User) Reset

func (x *User) Reset()

func (*User) String

func (x *User) String() string

type UserServiceClientProxy

type UserServiceClientProxy interface {
	GetUserInfo(ctx context.Context, req *GetUserInfoReq, opts ...client.Option) (rsp *GetUserInfoReq, err error)

	Hello(ctx context.Context, req *GetUserInfoReq, opts ...client.Option) (rsp *GetUserInfoReq, err error)

	Hello1(ctx context.Context, req *GetUserInfoReq, opts ...client.Option) (rsp *GetUserInfoReq, err error)
}

UserServiceClientProxy defines service client proxy

type UserServiceClientProxyImpl

type UserServiceClientProxyImpl struct {
	// contains filtered or unexported fields
}

func (*UserServiceClientProxyImpl) GetUserInfo

func (*UserServiceClientProxyImpl) Hello

func (*UserServiceClientProxyImpl) Hello1 added in v1.0.10

type UserServiceService

type UserServiceService interface {
	GetUserInfo(ctx context.Context, req *GetUserInfoReq) (*GetUserInfoReq, error)

	Hello(ctx context.Context, req *GetUserInfoReq) (*GetUserInfoReq, error)

	Hello1(ctx context.Context, req *GetUserInfoReq) (*GetUserInfoReq, error)
}

UserServiceService defines service.

Jump to